@@ -3,9 +3,8 @@ package MooX::VariantAttribute;
 use strict;
 use warnings;
 use Carp qw/croak/;
-use Scalar::Util qw/blessed/;
 use MooX::ReturnModifiers;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub import {
     my ( $package, @import ) = @_;
@@ -92,7 +91,7 @@ MooX::VariantAttribute - a щ（ﾟДﾟщ）Attribute...
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
@@ -203,11 +202,10 @@ objects are called with just the $new value.
     
     given => sub { my $self = shift; ref $_[0] },
 
-When is well when it gets a little more complicated to explain. *when* should always be an array reference of pairs. 
-The first value is the *matching* value it can be an SCALAR, ARRAY, HASH maybe even an Object. The second value has 
-to be an hash reference with two optional keys run and alias. *run* can either be a code reference or a scalar that
-references a sub routine available to $self, bot will be passed $self, the $value returned from given and the $new 
-passed value.
+*when* should always be an array reference of pairs. The first value is the *matching* value it can be an SCALAR, ARRAY, 
+HASH maybe even an Object. The second value has to be an hash reference with two optional keys run and alias. 
+*run* can either be a code reference or a scalar that references a sub routine available to $self, bot will be passed 
+$self, the $value returned from given and the $new passed value.
 
     package Backwards::World;
     use Moo;
