@@ -3,6 +3,7 @@ package MooX::VariantAttribute::Role;
 use Moo::Role;
 use Carp qw/croak/;
 use Scalar::Util qw/blessed refaddr reftype/;
+use Combine::Keys qw/combine_keys/;
 
 has variant_last_value => (
     is      => 'rw',
@@ -41,7 +42,7 @@ sub _given_when {
             }
 
             if ( my $run = $found->{run} ) { 
-                my @new = ref $run =~ m/^CODE|Type::Tiny$/
+                my @new = ref $run eq 'CODE' 
                     ? $found->{run}->( $self, $find, $set, ) 
                     : $self->$run($find, $set);
                 $set = scalar @new > 1 ? \@new : shift @new;
@@ -83,8 +84,7 @@ sub _struct_the_same {
     if ( $stored_ref eq 'SCALAR') {
           return ($stored =~ m/^$passed$/) ? 1 : undef;
     } elsif ($stored_ref eq 'HASH') {
-        my %cry = (%{$passed}, %{$stored});
-        for (keys %cry) {
+        for (combine_keys($stored, $passed)) {
             $stored->{$_} and $passed->{$_} or return undef;
             _struct_the_same($stored->{$_}, $passed->{$_}) or return undef;    
         }
